pysm Documentation — pysm v3.0.0

pysm:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- pysm v3.0.0 »
- pysm Documentation

# pysm Documentation

This is the documentation for pysm.

## Reference/API

### pysm Package

#### Functions

`apply_smoothing_and_coord_transform`(input_map) | Apply smoothing and coordinate rotation to an input map
`bandpass_unit_conversion`(freqs, weights, …) | Unit conversion from uK_RJ to output unit given a bandpass
`check_freq_input`(freqs) | Function to check that the input to `Model.get_emission` is a np.ndarray.
`mpi_smoothing`(input_map, fwhm, map_dist) |
`normalize_weights`(freqs, weights) |
`read_map`(path, nside[, unit, field, …]) | Wrapper of `healpy.read_map` for PySM data.
`test`(\*\*kwargs) | Run the tests for the package.

#### Classes

`CMBMap`(map_I, map_Q, map_U, nside[, map_dist]) |
`DecorrelatedModifiedBlackBody`([map_I, …]) | See parent class for other documentation.
`InterpolatingComponent`(path, input_units, nside) | PySM component interpolating between precomputed maps
`MapDistribution`([pixel_indices, mpi_comm, …]) | Define how a map is distributed
`Model`(nside[, map_dist, dataurl]) | This is the template object for PySM objects.
`ModifiedBlackBody`(map_I, map_Q, map_U, …) | This is a model for modified black body emission.
`PowerLaw`(map_I, freq_ref_I, map_pl_index, nside) | This is a model for a simple power law synchrotron model.
`Sky`([nside, component_objects, …]) | This class is a convenience object that wraps together a group of component models.
`SpDust`(map_I, freq_ref_I, emissivity, …[, …]) | Implementation of the SpDust2 code of (Ali-Haimoud et al 2012) evaluated for a Cold Neutral Medium.
`SpDustPol`(map_I, freq_ref_I, emissivity, …) | SpDust2 model with Polarized emission
`UnsupportedPythonError` |

#### Class Inheritance Diagram